@@ -1,4 +1,4 @@
-from RFEM.initModel import Model, clearAttributes, ConvertToDlString, ConvertStrToListOfInt
+from RFEM.initModel import Model, clearAttributes, deleteEmptyAttributes, ConvertToDlString, ConvertStrToListOfInt
 from RFEM.enums import LineType, LineArcAlphaAdjustmentTarget, ObjectTypes
 
 class Line():
@@ -38,6 +38,9 @@ class Line():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Line to client model
         model.clientModel.service.set_line(clientObject)
 
@@ -81,6 +84,9 @@ class Line():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Line to client model
         model.clientModel.service.set_line(clientObject)
 
@@ -134,6 +140,9 @@ class Line():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Line to client model
         model.clientModel.service.set_line(clientObject)
 
@@ -189,6 +198,9 @@ class Line():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Line to client model
         model.clientModel.service.set_line(clientObject)
 
@@ -252,6 +264,9 @@ class Line():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Line to client model
         model.clientModel.service.set_line(clientObject)
 
@@ -303,6 +318,9 @@ class Line():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Line to client model
         model.clientModel.service.set_line(clientObject)
 
@@ -358,6 +376,9 @@ class Line():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Line to client model
         model.clientModel.service.set_line(clientObject)
 
@@ -400,6 +421,9 @@ class Line():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Line to client model
         model.clientModel.service.set_line(clientObject)
 
@@ -443,7 +467,7 @@ class Line():
         # Order
         if control_points and weights and order:
             if len(control_points) != len(weights):
-                print("WARNING: The number of weigths prescribed must equal the number of control points defined.")
+                raise ValueError("WARNING: The number of weigths prescribed must equal the number of control points defined.")
             clientObject.nurbs_order = order
 
             # TODO: bug 24721
@@ -466,6 +490,9 @@ class Line():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Line to client model
         model.clientModel.service.set_line(clientObject)
 
