@@ -1,4 +1,4 @@
-from RFEM.initModel import Model, clearAttributes, ConvertToDlString
+from RFEM.initModel import Model, clearAttributes, deleteEmptyAttributes, ConvertToDlString
 from RFEM.enums import SetType
 
 class MemberSet():
@@ -43,6 +43,9 @@ class MemberSet():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Member Set to client model
         model.clientModel.service.set_member_set(clientObject)
 
@@ -86,6 +89,9 @@ class MemberSet():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Member Set to client model
         model.clientModel.service.set_member_set(clientObject)
 
@@ -129,5 +135,8 @@ class MemberSet():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Member Set to client model
         model.clientModel.service.set_member_set(clientObject)
