@@ -1,5 +1,5 @@
 from RFEM.enums import SurfaceGeometry, SurfaceLoadDistributionDirection, SurfaceType, ObjectTypes
-from RFEM.initModel import Model, clearAttributes, ConvertToDlString, ConvertStrToListOfInt
+from RFEM.initModel import Model, clearAttributes, deleteEmptyAttributes, ConvertToDlString, ConvertStrToListOfInt
 import math
 
 def CreateGeometryAndSetToModel(no, surface_type, boundary_lines_no, geometry_type, geometry_type_parameters, thickness = None, comment = None, params = None, model = Model):
@@ -39,10 +39,10 @@ def CreateGeometryAndSetToModel(no, surface_type, boundary_lines_no, geometry_ty
     boundary_lines_list = boundary_lines_no.split(sep= ' ')
     if geometry_type.name == 'GEOMETRY_NURBS':
         if len(geometry_type_parameters) != 4:
-            raise Exception('WARNING: The geometry type parameter needs to be of length 4. Kindly check list inputs for completeness and correctness.')
+            raise ValueError('WARNING: The geometry type parameter needs to be of length 4. Kindly check list inputs for completeness and correctness.')
         for line in boundary_lines_list:
             if model.clientModel.service.get_line(int(line))['type'] != 'TYPE_NURBS':
-                raise Exception('WARNING: For a NURBS Surface, the boundary lines need to be NURBS Curves')
+                raise ValueError('WARNING: For a NURBS Surface, the boundary lines need to be NURBS Curves')
         clientObject.nurbs_control_point_count_in_direction_u = geometry_type_parameters[0]
         clientObject.nurbs_control_point_count_in_direction_v = geometry_type_parameters[1]
         clientObject.nurbs_order_in_direction_u = geometry_type_parameters[2]
@@ -60,7 +60,7 @@ def CreateGeometryAndSetToModel(no, surface_type, boundary_lines_no, geometry_ty
         clientObject.rotated_boundary_line = geometry_type_parameters[3]
     elif geometry_type.name == 'GEOMETRY_QUADRANGLE':
         if len(geometry_type_parameters) != 4:
-            raise Exception('WARNING: The geometry type parameter needs to be of length 4. Kindly check list inputs for completeness and correctness.')
+            raise ValueError('WARNING: The geometry type parameter needs to be of length 4. Kindly check list inputs for completeness and correctness.')
         clientObject.quadrangle_corner_node_1 = geometry_type_parameters[0]
         clientObject.quadrangle_corner_node_2 = geometry_type_parameters[1]
         clientObject.quadrangle_corner_node_3 = geometry_type_parameters[2]
@@ -127,6 +127,9 @@ class Surface():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Surface to client model
         model.clientModel.service.set_surface(clientObject)
 
@@ -355,7 +358,7 @@ class Surface():
         if loaded_lines is not None:
             clientObject.loaded_lines = ConvertToDlString(loaded_lines)
         if loaded_lines is None and loaded_members is None:
-            raise Exception('WARNING: Loaded lines and/or members need to be specified.')
+            raise ValueError('WARNING: Loaded lines and/or members need to be specified.')
 
         # Comment
         clientObject.comment = comment
@@ -365,6 +368,9 @@ class Surface():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Surface to client model
         model.clientModel.service.set_surface(clientObject)
 
