@@ -1,5 +1,6 @@
-from RFEM.initModel import Model, clearAttributes
+from RFEM.initModel import Model, clearAttributes, deleteEmptyAttributes
 from RFEM.enums import AnalysisType, ActionCategoryType
+from RFEM.LoadCasesAndCombinations.loadCasesAndCombinations import LoadCasesAndCombinations
 
 
 class LoadCase():
@@ -8,6 +9,7 @@ class LoadCase():
                  no: int = 1,
                  name: str = 'Self-weight',
                  self_weight: list = [True, 0.0, 0.0, 1.0],
+                 action_category=ActionCategoryType.ACTION_CATEGORY_NONE_NONE,
                  comment: str = 'Comment',
                  params: dict = None,
                  model = Model):
@@ -15,6 +17,7 @@ class LoadCase():
         Args:
             no (int): Load Case Tag
             name (str): Load Case Name
+            action_category (enum) = Action Category Type Enumeration
             self_weight (list): Self-Weight Parameters
                 self_weight = [self_weight_active, self_weight_factor_x, self_weight_factor_y, self_weight_factor_z]
             comment (str, optional): Comments
@@ -42,24 +45,23 @@ class LoadCase():
         clientObject.static_analysis_settings = 1
 
         # Action Category
-        clientObject.action_category = ActionCategoryType.ACTION_CATEGORY_PERMANENT_G.name
+        if action_category.name not in LoadCasesAndCombinations.getAvailableLoadActionCategoryTypes():
+            raise ValueError('WARNING: The selected Action Category is not available under the defined Standard.')
+        clientObject.action_category = action_category.name
 
         # Self-weight Considerations
         clientObject.self_weight_active = self_weight[0]
         if not isinstance(self_weight[0], bool):
-            raise Exception(
-                'WARNING: Entry at index 0 of Self-Weight parameter to be of type bool')
+            raise ValueError('WARNING: Entry at index 0 of Self-Weight parameter to be of type bool')
         if self_weight[0]:
             if len(self_weight) != 4:
-                raise Exception(
-                    'WARNING: Self-weight is activated and therefore requires a list definition of length 4. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: Self-weight is activated and therefore requires a list definition of length 4. Kindly check list inputs for completeness and correctness.')
             clientObject.self_weight_factor_x = self_weight[1]
             clientObject.self_weight_factor_y = self_weight[2]
             clientObject.self_weight_factor_z = self_weight[3]
         else:
             if len(self_weight) != 1:
-                raise Exception(
-                    'WARNING: Self-weight is deactivated and therefore requires a list definition of length 1. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: Self-weight is deactivated and therefore requires a list definition of length 1. Kindly check list inputs for completeness and correctness.')
 
         # Comment
         clientObject.comment = comment
@@ -69,6 +71,9 @@ class LoadCase():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Load Case to client model
         model.clientModel.service.set_load_case(clientObject)
 
@@ -78,7 +83,7 @@ class LoadCase():
             name: str = 'Self-weight',
             to_solve: bool = True,
             analysis_settings_no: int = 1,
-            action_category=ActionCategoryType.ACTION_CATEGORY_PERMANENT_G,
+            action_category=ActionCategoryType.ACTION_CATEGORY_NONE_NONE,
             self_weight: list =[True, 0.0, 0.0, 10.0],
             comment: str = 'Comment',
             params: dict = None,
@@ -120,24 +125,23 @@ class LoadCase():
         clientObject.static_analysis_settings = analysis_settings_no
 
         # Action Category
+        if action_category.name not in LoadCasesAndCombinations.getAvailableLoadActionCategoryTypes():
+            raise ValueError('WARNING: The selected Action Category is not available under the defined Standard.')
         clientObject.action_category = action_category.name
 
         # Self-weight Considerations
         clientObject.self_weight_active = self_weight[0]
         if not isinstance(self_weight[0], bool):
-            raise Exception(
-                'WARNING: Entry at index 0 of Self-Weight parameter to be of type bool')
+            raise ValueError('WARNING: Entry at index 0 of Self-Weight parameter to be of type bool')
         if self_weight[0]:
             if len(self_weight) != 4:
-                raise Exception(
-                    'WARNING: Self-weight is activated and therefore requires a list definition of length 4. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: Self-weight is activated and therefore requires a list definition of length 4. Kindly check list inputs for completeness and correctness.')
             clientObject.self_weight_factor_x = self_weight[1]
             clientObject.self_weight_factor_y = self_weight[2]
             clientObject.self_weight_factor_z = self_weight[3]
         else:
             if len(self_weight) != 1:
-                raise Exception(
-                    'WARNING: Self-weight is deactivated and therefore requires a list definition of length 1. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: Self-weight is deactivated and therefore requires a list definition of length 1. Kindly check list inputs for completeness and correctness.')
 
         # Comment
         clientObject.comment = comment
@@ -147,5 +151,8 @@ class LoadCase():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Load Case to client model
         model.clientModel.service.set_load_case(clientObject)
