@@ -1,4 +1,4 @@
-from RFEM.initModel import Model, ConvertToDlString, clearAttributes
+from RFEM.initModel import Model, ConvertToDlString, clearAttributes, deleteEmptyAttributes
 from RFEM.enums import *
 
 class LineSetLoad():
@@ -65,6 +65,9 @@ class LineSetLoad():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Load Lineset Load to client model
         model.clientModel.service.set_line_set_load(load_case_no, clientObject)
 
@@ -144,9 +147,9 @@ class LineSetLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_CONCENTRATED_1":
             if len(load_parameter) != 3:
-                raise Exception('WARNING: The load parameter needs to be of length 3. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: The load parameter needs to be of length 3. Kindly check list inputs for completeness and correctness.')
             if not isinstance(load_parameter[0], bool):
-                raise Exception ('WARNING: Load parameter at index 0 to be of type "bool"')
+                raise ValueError('WARNING: Load parameter at index 0 to be of type "bool"')
             clientObject.distance_a_is_defined_as_relative = load_parameter[0]
             if not load_parameter[0]:
                 clientObject.magnitude = load_parameter[1]
@@ -157,9 +160,9 @@ class LineSetLoad():
 
         elif load_distribution.name ==  "LOAD_DISTRIBUTION_CONCENTRATED_N":
             if len(load_parameter) != 6:
-                raise Exception('WARNING: The load parameter needs to be of length 6. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: The load parameter needs to be of length 6. Kindly check list inputs for completeness and correctness.')
             if not isinstance(load_parameter[0], bool):
-                raise Exception ('WARNING: Load parameter at index 0 to be of type "bool"')
+                raise ValueError('WARNING: Load parameter at index 0 to be of type "bool"')
             clientObject.distance_a_is_defined_as_relative = load_parameter[0]
             clientObject.distance_b_is_defined_as_relative = load_parameter[1]
             clientObject.magnitude = load_parameter[2]
@@ -177,9 +180,9 @@ class LineSetLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_CONCENTRATED_2x2":
             if len(load_parameter) != 7:
-                raise Exception('WARNING: The load parameter needs to be of length 7. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: The load parameter needs to be of length 7. Kindly check list inputs for completeness and correctness.')
             if not isinstance(load_parameter[0], bool) or not isinstance(load_parameter[1], bool) or not isinstance(load_parameter[2], bool):
-                raise Exception ('WARNING: Load parameter at index 0, 1 and 2 to be of type "bool"')
+                raise ValueError('WARNING: Load parameter at index 0, 1 and 2 to be of type "bool"')
             clientObject.distance_a_is_defined_as_relative = load_parameter[0]
             clientObject.distance_b_is_defined_as_relative = load_parameter[1]
             clientObject.distance_c_is_defined_as_relative = load_parameter[2]
@@ -202,9 +205,9 @@ class LineSetLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_CONCENTRATED_2":
             if len(load_parameter) != 6:
-                raise Exception('WARNING: The load parameter needs to be of length 6. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: The load parameter needs to be of length 6. Kindly check list inputs for completeness and correctness.')
             if not isinstance(load_parameter[0], bool) or not isinstance(load_parameter[1], bool):
-                raise Exception ('WARNING: Load parameter at index 0 and 1 to be of type "bool"')
+                raise ValueError('WARNING: Load parameter at index 0 and 1 to be of type "bool"')
             clientObject.distance_a_is_defined_as_relative = load_parameter[0]
             clientObject.distance_b_is_defined_as_relative = load_parameter[1]
             clientObject.magnitude_1 = load_parameter[2]
@@ -221,16 +224,10 @@ class LineSetLoad():
                 clientObject.distance_b_relative = load_parameter[5]
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_CONCENTRATED_VARYING":
-            try:
-                len(load_parameter[0])==3
-            except:
-                print("WARNING: LineLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
-
             clientObject.varying_load_parameters = Model.clientModel.factory.create('ns0:line_load.varying_load_parameters')
-
             for i,j in enumerate(load_parameter):
                 if len(load_parameter[i]) != 3:
-                    raise Exception('WARNING: The load parameter sub-lists need to be of length 3. Kindly check sub-list inputs for completeness and correctness.')
+                    raise ValueError("WARNING: LineLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
                 mlvlp = Model.clientModel.factory.create('ns0:line_set_load_varying_load_parameters_row')
                 mlvlp.no = i+1
                 mlvlp.row.distance = load_parameter[i][0]
@@ -242,9 +239,9 @@ class LineSetLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_TRAPEZOIDAL":
             if len(load_parameter) != 6:
-                raise Exception('WARNING: The load parameter needs to be of length 6. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: The load parameter needs to be of length 6. Kindly check list inputs for completeness and correctness.')
             if not isinstance(load_parameter[0], bool) or not isinstance(load_parameter[1], bool):
-                raise Exception ('WARNING: Load parameter at index 0 and 1 to be of type "bool"')
+                raise ValueError('WARNING: Load parameter at index 0 and 1 to be of type "bool"')
             clientObject.distance_a_is_defined_as_relative = load_parameter[0]
             clientObject.distance_b_is_defined_as_relative = load_parameter[1]
             clientObject.magnitude_1 = load_parameter[2]
@@ -262,9 +259,9 @@ class LineSetLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_TAPERED":
             if len(load_parameter) != 6:
-                raise Exception('WARNING: The load parameter needs to be of length 6. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: The load parameter needs to be of length 6. Kindly check list inputs for completeness and correctness.')
             if not isinstance(load_parameter[0], bool) or not isinstance(load_parameter[1], bool):
-                raise Exception ('WARNING: Load parameter at index 0 and 1 to be of type "bool"')
+                raise ValueError('WARNING: Load parameter at index 0 and 1 to be of type "bool"')
             clientObject.distance_a_is_defined_as_relative = load_parameter[0]
             clientObject.distance_b_is_defined_as_relative = load_parameter[1]
             clientObject.magnitude_1 = load_parameter[2]
@@ -282,21 +279,16 @@ class LineSetLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_PARABOLIC":
             if len(load_parameter) != 3:
-                raise Exception('WARNING: The load parameter needs to be of length 3. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: The load parameter needs to be of length 3. Kindly check list inputs for completeness and correctness.')
             clientObject.magnitude_1 = load_parameter[0]
             clientObject.magnitude_2 = load_parameter[1]
             clientObject.magnitude_3 = load_parameter[2]
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_VARYING":
-            try:
-                len(load_parameter[0])==3
-            except:
-                print("WARNING: LineLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
-
             clientObject.varying_load_parameters = Model.clientModel.factory.create('ns0:line_set_load.varying_load_parameters')
             for i,j in enumerate(load_parameter):
                 if len(load_parameter[i]) != 3:
-                    raise Exception('WARNING: The load parameter sub-lists need to be of length 3. Kindly check sub-list inputs for completeness and correctness.')
+                    raise ValueError("WARNING: LineLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
                 mlvlp = Model.clientModel.factory.create('ns0:line_set_load_varying_load_parameters_row')
                 mlvlp.no = i+1
                 mlvlp.row.distance = load_parameter[i][0]
@@ -320,6 +312,9 @@ class LineSetLoad():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Load Line Load to client model
         model.clientModel.service.set_line_set_load(load_case_no, clientObject)
 
@@ -396,9 +391,9 @@ class LineSetLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_CONCENTRATED_1":
             if len(load_parameter) != 3:
-                raise Exception('WARNING: The load parameter needs to be of length 3. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: The load parameter needs to be of length 3. Kindly check list inputs for completeness and correctness.')
             if not isinstance(load_parameter[0], bool):
-                raise Exception ('WARNING: Load parameter at index 0 to be of type "bool"')
+                raise ValueError('WARNING: Load parameter at index 0 to be of type "bool"')
             clientObject.distance_a_is_defined_as_relative = load_parameter[0]
             if not load_parameter[0]:
                 clientObject.magnitude = load_parameter[1]
@@ -409,9 +404,9 @@ class LineSetLoad():
 
         elif load_distribution.name ==  "LOAD_DISTRIBUTION_CONCENTRATED_N":
             if len(load_parameter) != 6:
-                raise Exception('WARNING: The load parameter needs to be of length 6. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: The load parameter needs to be of length 6. Kindly check list inputs for completeness and correctness.')
             if not isinstance(load_parameter[0], bool):
-                raise Exception ('WARNING: Load parameter at index 0 to be of type "bool"')
+                raise ValueError('WARNING: Load parameter at index 0 to be of type "bool"')
             clientObject.distance_a_is_defined_as_relative = load_parameter[0]
             clientObject.distance_b_is_defined_as_relative = load_parameter[1]
             clientObject.magnitude = load_parameter[2]
@@ -429,9 +424,9 @@ class LineSetLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_CONCENTRATED_2x2":
             if len(load_parameter) != 7:
-                raise Exception('WARNING: The load parameter needs to be of length 7. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: The load parameter needs to be of length 7. Kindly check list inputs for completeness and correctness.')
             if not isinstance(load_parameter[0], bool) or not isinstance(load_parameter[1], bool) or not isinstance(load_parameter[2], bool):
-                raise Exception ('WARNING: Load parameter at index 0, 1 and 2 to be of type "bool"')
+                raise ValueError('WARNING: Load parameter at index 0, 1 and 2 to be of type "bool"')
             clientObject.distance_a_is_defined_as_relative = load_parameter[0]
             clientObject.distance_b_is_defined_as_relative = load_parameter[1]
             clientObject.distance_c_is_defined_as_relative = load_parameter[2]
@@ -454,9 +449,9 @@ class LineSetLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_CONCENTRATED_2":
             if len(load_parameter) != 6:
-                raise Exception('WARNING: The load parameter needs to be of length 6. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: The load parameter needs to be of length 6. Kindly check list inputs for completeness and correctness.')
             if not isinstance(load_parameter[0], bool) or not isinstance(load_parameter[1], bool):
-                raise Exception ('WARNING: Load parameter at index 0 and 1 to be of type "bool"')
+                raise ValueError('WARNING: Load parameter at index 0 and 1 to be of type "bool"')
             clientObject.distance_a_is_defined_as_relative = load_parameter[0]
             clientObject.distance_b_is_defined_as_relative = load_parameter[1]
             clientObject.magnitude_1 = load_parameter[2]
@@ -473,16 +468,11 @@ class LineSetLoad():
                 clientObject.distance_b_relative = load_parameter[5]
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_CONCENTRATED_VARYING":
-            try:
-                len(load_parameter[0])==3
-            except:
-                print("WARNING: LineLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
-
             clientObject.varying_load_parameters = Model.clientModel.factory.create('ns0:line_load.varying_load_parameters')
 
             for i,j in enumerate(load_parameter):
                 if len(load_parameter[i]) != 3:
-                    raise Exception('WARNING: The load parameter sub-lists need to be of length 3. Kindly check sub-list inputs for completeness and correctness.')
+                    raise ValueError("WARNING: LineLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
                 mlvlp = Model.clientModel.factory.create('ns0:line_set_load_varying_load_parameters_row')
                 mlvlp.no = i+1
                 mlvlp.row.distance = load_parameter[i][0]
@@ -494,9 +484,9 @@ class LineSetLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_TRAPEZOIDAL":
             if len(load_parameter) != 6:
-                raise Exception('WARNING: The load parameter needs to be of length 6. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: The load parameter needs to be of length 6. Kindly check list inputs for completeness and correctness.')
             if not isinstance(load_parameter[0], bool) or not isinstance(load_parameter[1], bool):
-                raise Exception ('WARNING: Load parameter at index 0 and 1 to be of type "bool"')
+                raise ValueError('WARNING: Load parameter at index 0 and 1 to be of type "bool"')
             clientObject.distance_a_is_defined_as_relative = load_parameter[0]
             clientObject.distance_b_is_defined_as_relative = load_parameter[1]
             clientObject.magnitude_1 = load_parameter[2]
@@ -514,9 +504,9 @@ class LineSetLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_TAPERED":
             if len(load_parameter) != 6:
-                raise Exception('WARNING: The load parameter needs to be of length 6. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: The load parameter needs to be of length 6. Kindly check list inputs for completeness and correctness.')
             if not isinstance(load_parameter[0], bool) or not isinstance(load_parameter[1], bool):
-                raise Exception ('WARNING: Load parameter at index 0 and 1 to be of type "bool"')
+                raise ValueError('WARNING: Load parameter at index 0 and 1 to be of type "bool"')
             clientObject.distance_a_is_defined_as_relative = load_parameter[0]
             clientObject.distance_b_is_defined_as_relative = load_parameter[1]
             clientObject.magnitude_1 = load_parameter[2]
@@ -534,21 +524,16 @@ class LineSetLoad():
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_PARABOLIC":
             if len(load_parameter) != 3:
-                raise Exception('WARNING: The load parameter needs to be of length 3. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: The load parameter needs to be of length 3. Kindly check list inputs for completeness and correctness.')
             clientObject.magnitude_1 = load_parameter[0]
             clientObject.magnitude_2 = load_parameter[1]
             clientObject.magnitude_3 = load_parameter[2]
 
         elif load_distribution.name == "LOAD_DISTRIBUTION_VARYING":
-            try:
-                len(load_parameter[0])==3
-            except:
-                print("WARNING: LineLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
-
             clientObject.varying_load_parameters = Model.clientModel.factory.create('ns0:line_set_load.varying_load_parameters')
             for i,j in enumerate(load_parameter):
                 if len(load_parameter[i]) != 3:
-                    raise Exception('WARNING: The load parameter sub-lists need to be of length 3. Kindly check sub-list inputs for completeness and correctness.')
+                    raise ValueError("WARNING: LineLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
                 mlvlp = Model.clientModel.factory.create('ns0:line_set_load_varying_load_parameters_row')
                 mlvlp.no = i+1
                 mlvlp.row.distance = load_parameter[i][0]
@@ -572,6 +557,9 @@ class LineSetLoad():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Load Lineset Load to client model
         model.clientModel.service.set_line_set_load(load_case_no, clientObject)
 
@@ -626,17 +614,17 @@ class LineSetLoad():
 
         # Individual Mass Components
         if not isinstance(individual_mass_components, bool):
-            raise Exception('WARNING: Input to be of type "bool"')
+            raise ValueError('WARNING: Input to be of type "bool"')
         clientObject.individual_mass_components = individual_mass_components
 
         # Mass magnitude
         if not individual_mass_components:
             if len(mass_components) != 1:
-                raise Exception('WARNING: The mass components parameter for global mass assignment needs to be of length 1. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: The mass components parameter for global mass assignment needs to be of length 1. Kindly check list inputs for completeness and correctness.')
             clientObject.mass_global = mass_components[0]
         else:
             if len(mass_components) != 3:
-                raise Exception('WARNING: The mass components parameter for individual mass component assignment needs to be of length 3. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: The mass components parameter for individual mass component assignment needs to be of length 3. Kindly check list inputs for completeness and correctness.')
             clientObject.mass_x = mass_components[0]
             clientObject.mass_y = mass_components[1]
             clientObject.mass_z = mass_components[2]
@@ -649,5 +637,8 @@ class LineSetLoad():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Load Line Load to client model
         model.clientModel.service.set_line_set_load(load_case_no, clientObject)
