@@ -1,4 +1,4 @@
-from RFEM.initModel import Model, clearAttributes, ConvertToDlString
+from RFEM.initModel import Model, clearAttributes, deleteEmptyAttributes, ConvertToDlString
 from RFEM.enums import LoadDirectionType, NodalLoadType, NodalLoadSpecificDirectionType
 
 class NodalLoad():
@@ -56,6 +56,9 @@ class NodalLoad():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Nodal Force to client model
         model.clientModel.service.set_nodal_load(load_case_no, clientObject)
 
@@ -127,13 +130,13 @@ class NodalLoad():
 
         #Option Check
         if force_eccentricity and shifted_display:
-            raise Exception("Only one of force_eccentiricity and shifted_display could be TRUE")
+            raise ValueError("Only one of force_eccentiricity and shifted_display could be TRUE")
 
         # Specific Direction
         if specific_direction:
 
             if 'specific_direction' not in list(params.keys()):
-                raise Exception("Required key is missing")
+                raise ValueError("Required key is missing")
 
             params_s = params['specific_direction']
 
@@ -166,7 +169,7 @@ class NodalLoad():
         if force_eccentricity:
 
             if 'force_eccentricity' not in list(params.keys()):
-                raise Exception("Required key is missing")
+                raise ValueError("Required key is missing")
 
             params_e = params['force_eccentricity']
 
@@ -180,7 +183,7 @@ class NodalLoad():
         if shifted_display:
 
             if 'shifted_display' not in list(params.keys()):
-                raise Exception("Required key is missing")
+                raise ValueError("Required key is missing")
 
             params_d = params['shifted_display']
 
@@ -201,6 +204,9 @@ class NodalLoad():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Nodal Force to client model
         model.clientModel.service.set_nodal_load(load_case_no, clientObject)
 
@@ -270,7 +276,7 @@ class NodalLoad():
         if specific_direction:
 
             if 'specific_direction' not in list(params.keys()):
-                raise Exception("Required key is missing")
+                raise ValueError("Required key is missing")
 
             params_s = params['specific_direction']
 
@@ -303,7 +309,7 @@ class NodalLoad():
         if shifted_display:
 
             if 'shifted_display' not in list(params.keys()):
-                raise Exception("Required key is missing")
+                raise ValueError("Required key is missing")
 
             params_d = params['shifted_display']
 
@@ -324,6 +330,9 @@ class NodalLoad():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Nodal Force to client model
         model.clientModel.service.set_nodal_load(load_case_no, clientObject)
 
@@ -392,17 +401,17 @@ class NodalLoad():
             clientObject.components_moment_y = components[4]
             clientObject.components_moment_z = components[5]
         else:
-            raise Exception("WARNING: The components must contain 6 elements. Kindly check list inputs for completeness and correctness.")
+            raise ValueError("WARNING: The components must contain 6 elements. Kindly check list inputs for completeness and correctness.")
 
         #Option Check
         if force_eccentricity and shifted_display:
-            raise Exception("WARNING: Only one of force_eccentiricity and shifted_display could be TRUE")
+            raise ValueError("WARNING: Only one of force_eccentiricity and shifted_display could be TRUE")
 
         # Specific Direction
         if specific_direction:
 
             if 'specific_direction' not in list(params.keys()):
-                raise Exception("Required key is missing")
+                raise ValueError("Required key is missing")
 
             params_s = params['specific_direction']
 
@@ -428,7 +437,7 @@ class NodalLoad():
         if force_eccentricity:
 
             if 'force_eccentricity' not in list(params.keys()):
-                raise Exception("Required key is missing")
+                raise ValueError("Required key is missing")
 
             params_e = params['force_eccentricity']
 
@@ -442,7 +451,7 @@ class NodalLoad():
         if shifted_display:
 
             if 'shifted_display' not in list(params.keys()):
-                raise Exception("Required key is missing")
+                raise ValueError("Required key is missing")
 
             params_d = params['shifted_display']
 
@@ -463,6 +472,9 @@ class NodalLoad():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Nodal Force to client model
         model.clientModel.service.set_nodal_load(load_case_no, clientObject)
 
@@ -534,5 +546,8 @@ class NodalLoad():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Nodal Force to client model
         model.clientModel.service.set_nodal_load(load_case_no, clientObject)
