@@ -1,5 +1,5 @@
-from RFEM.initModel import *
-from RFEM.enums import *
+from RFEM.initModel import Model, clearAttributes, ConvertToDlString, deleteEmptyAttributes
+from RFEM.enums import OpeningLoadDistribution, OpeningLoadDirection
 
 class OpeningLoad():
 
@@ -75,5 +75,8 @@ class OpeningLoad():
         for key in params:
             clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Opening Load to client model
         Model.clientModel.service.set_opening_load(load_case_no, clientObject)
