@@ -1,4 +1,4 @@
-from RFEM.initModel import Model, clearAttributes, ConvertToDlString
+from RFEM.initModel import Model, clearAttributes, deleteEmptyAttributes, ConvertToDlString
 from RFEM.enums import SolidSetLoadType, SolidSetLoadDistribution, SolidSetLoadDirection
 
 class SolidSetLoad():
@@ -63,6 +63,9 @@ class SolidSetLoad():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Solid Load to client model
         model.clientModel.service.set_solid_set_load(load_case_no, clientObject)
 
@@ -123,6 +126,9 @@ class SolidSetLoad():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Solid Load to client model
         model.clientModel.service.set_solid_set_load(load_case_no, clientObject)
 
@@ -192,6 +198,9 @@ class SolidSetLoad():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Solid Load to client model
         model.clientModel.service.set_solid_set_load(load_case_no, clientObject)
 
@@ -267,6 +276,9 @@ class SolidSetLoad():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Solid Load to client model
         model.clientModel.service.set_solid_set_load(load_case_no, clientObject)
 
@@ -330,6 +342,9 @@ class SolidSetLoad():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Solid Load to client model
         model.clientModel.service.set_solid_set_load(load_case_no, clientObject)
 
