@@ -1,4 +1,4 @@
-from RFEM.initModel import Model, clearAttributes, ConvertToDlString
+from RFEM.initModel import Model, clearAttributes, deleteEmptyAttributes, ConvertToDlString
 from RFEM.enums import SurfaceSetLoadType, SurfaceSetLoadDirection, SurfaceSetLoadDistribution, SurfaceSetLoadAxisDefinitionType
 
 class SurfaceSetLoad():
@@ -55,6 +55,9 @@ class SurfaceSetLoad():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Surface Load to client model
         model.clientModel.service.set_surface_set_load(load_case_no, clientObject)
 
@@ -185,6 +188,9 @@ class SurfaceSetLoad():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Surface Load to client model
         model.clientModel.service.set_surface_set_load(load_case_no, clientObject)
 
@@ -298,6 +304,9 @@ class SurfaceSetLoad():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Surface Load to client model
         model.clientModel.service.set_surface_set_load(load_case_no, clientObject)
 
@@ -387,6 +396,9 @@ class SurfaceSetLoad():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Surface Load to client model
         model.clientModel.service.set_surface_set_load(load_case_no, clientObject)
 
@@ -443,6 +455,9 @@ class SurfaceSetLoad():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Surface Load to client model
         model.clientModel.service.set_surface_set_load(load_case_no, clientObject)
 
@@ -514,6 +529,9 @@ class SurfaceSetLoad():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Surface Load to client model
         model.clientModel.service.set_surface_set_load(load_case_no, clientObject)
 
@@ -578,5 +596,8 @@ class SurfaceSetLoad():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Surface Load to client model
         model.clientModel.service.set_surface_set_load(load_case_no, clientObject)
