@@ -1,4 +1,4 @@
-from RFEM.initModel import Model, clearAttributes
+from RFEM.initModel import Model, clearAttributes, deleteEmptyAttributes
 
 class Instersection():
     def __init__(self,
@@ -41,5 +41,8 @@ class Instersection():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Intersection to client model
         model.clientModel.service.set_intersection(clientObject)
