@@ -1,5 +1,5 @@
-from RFEM.initModel import Model, clearAttributes
-from RFEM.enums import *
+from RFEM.initModel import Model, clearAttributes, deleteEmptyAttributes
+from RFEM.enums import RigidLinkType
 
 class RigidLink():
     def __init__(self,
@@ -51,6 +51,9 @@ class RigidLink():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add rigid link to client model
         model.clientModel.service.set_rigid_link(clientObject)
 
@@ -103,6 +106,9 @@ class RigidLink():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add rigid link to client model
         model.clientModel.service.set_rigid_link(clientObject)
 
@@ -156,6 +162,9 @@ class RigidLink():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add rigid link to client model
         model.clientModel.service.set_rigid_link(clientObject)
 
@@ -203,5 +212,8 @@ class RigidLink():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add rigid link to client model
         model.clientModel.service.set_rigid_link(clientObject)
