@@ -1,7 +1,8 @@
-from RFEM.initModel import Model, clearAttributes, ConvertStrToListOfInt
+from RFEM.initModel import Model, clearAttributes, deleteEmptyAttributes, ConvertStrToListOfInt
 from RFEM.enums import LineWeldedJointType, WeldType, WeldLongitudalArrangement
 
 class LineWeldedJoint():
+
     def __init__(self,
                  no: int = 1,
                  lines: str = '5',
@@ -56,6 +57,9 @@ class LineWeldedJoint():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Line welded joint to client model
         model.clientModel.service.set_line_welded_joint(clientObject)
 
