@@ -1,5 +1,5 @@
 from RFEM.enums import MemberHingeNonlinearity
-from RFEM.initModel import ConvertToDlString, Model, clearAttributes
+from RFEM.initModel import Model, clearAttributes, ConvertToDlString, deleteEmptyAttributes
 from RFEM.dataTypes import inf
 
 class MemberHinge():
@@ -480,5 +480,8 @@ class MemberHinge():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Line to client model
         model.clientModel.service.set_member_hinge(clientObject)
