@@ -1,4 +1,4 @@
-from RFEM.initModel import Model, clearAttributes, ConvertToDlString
+from RFEM.initModel import Model, clearAttributes, deleteEmptyAttributes, ConvertToDlString
 from RFEM.dataTypes import inf
 from RFEM.enums import NodalSupportType
 
@@ -109,5 +109,8 @@ class NodalSupport():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Nodal Support to client model
         model.clientModel.service.set_nodal_support(clientObject)
