@@ -1,10 +1,10 @@
-from RFEM.initModel import Model, clearAttributes, ConvertToDlString, GetAddonStatus, SetAddonStatus
-from RFEM.enums import *
+from RFEM.initModel import Model, clearAttributes, deleteEmptyAttributes, ConvertToDlString, GetAddonStatus, SetAddonStatus
+from RFEM.enums import AddOn, SteelMemberRotationalRestraintType
 
 class SteelMemberRotationalRestraint():
     def __init__(self,
                 no: int = 1,
-                user_defined_name: list = [False],
+                name: str = '',
                 definition_type = SteelMemberRotationalRestraintType.TYPE_CONTINUOUS,
                 members: str = "",
                 member_sets: str = "",
@@ -16,11 +16,7 @@ class SteelMemberRotationalRestraint():
         """
         Args:
             no (int): Steel Member Rotational Restraint Tag
-            user_defined_name (list): User Defined Member Rotational Restraint Name
-                for user_defined_name[0] == False:
-                    pass
-                for user_defined_name == True:
-                    user_defined_name[1] = Defined Name
+            name (str): User Defined Member Rotational Restraint Name
             definition_type (enum): Steel Member Rotational Restraint Type Enumeration
             members (str): Assigned Members
             member_sets (str): Assigned Member Sets
@@ -63,7 +59,7 @@ class SteelMemberRotationalRestraint():
         # Deducing RFEM Language from steel_design_addon String:
         modelInfo = Model.clientModel.service.get_model_info()
         if modelInfo.property_addon_steel_design.split()[0] != 'Steel':
-            raise Exception("WARNING: The steelMemberRotationalRestraints operates with the RFEM Application set to English. Kindly switch RFEM to English such that Database searches can completed successfully.")
+            raise ValueError("WARNING: The steelMemberRotationalRestraints operates with the RFEM Application set to English. Kindly switch RFEM to English such that Database searches can completed successfully.")
 
         # Check if Steel Design Add-on is ON.
         if not GetAddonStatus(model.clientModel, AddOn.steel_design_active):
@@ -85,11 +81,9 @@ class SteelMemberRotationalRestraint():
         clientObject.member_sets = ConvertToDlString(member_sets)
 
         # Member Rotational Restraint Name
-        if user_defined_name[0]:
-            clientObject.user_defined_name_enabled = user_defined_name[0]
-            clientObject.name = user_defined_name[1]
-        else:
-            clientObject.user_defined_name_enabled = user_defined_name[0]
+        if name:
+            clientObject.user_defined_name_enabled = True
+            clientObject.name = name
 
         # Member Rotational Restraint Definition Type
         clientObject.type = definition_type.name
@@ -135,10 +129,8 @@ class SteelMemberRotationalRestraint():
             for key in params:
                 clientObject[key] = params[key]
 
-        # Adding Steel Member Rotational Restraint to Client Model
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
+        # Add Steel Member Rotational Restraint to Client Model
         model.clientModel.service.set_steel_member_rotational_restraint(clientObject)
-
-
-
-
-
